@@ -17,7 +17,7 @@ from sys import exit
 # custom libs and constants
 from .console_logging import CONSOLE, header, sub_header
 from .env_config import check_os_support, HOME_DIR, USR_CONFIG_FILE, VERSION
-from .env_config import XDG_CACHE_DIR
+from .env_config import XDG_CACHE_DIR, KUBECONFIG
 from .help_text import RichCommand, options_help
 
 
@@ -130,8 +130,10 @@ def delete_cluster(k8s_distro="k3s"):
 @option('--delete', '-D', is_flag=True, help=HELP['delete'])
 @option('--external_secret_operator', '-e', is_flag=True,
         help=HELP['external_secret_operator'])
+@option('--extras', '-E', is_flag=True, help=HELP['extras'])
 @option('--kyverno', '-k', is_flag=True, help=HELP['kyverno'])
 @option('--k9s', '-K', is_flag=True, help=HELP['k9s'])
+@option('--minio', '-m', is_flag=True, help=HELP['minio'])
 @option('--log_level', '-l', metavar='LOGLEVEL', help=HELP['log_level'],
         type=Choice(['debug', 'info', 'warn', 'error']))
 @option('--log_file', '-o', metavar='LOGFILE', help=HELP['log_file'])
@@ -143,11 +145,13 @@ def main(k8s: str = "",
          config: str = "",
          delete: bool = False,
          external_secret_operator: bool = False,
+         extras: bool = False,
          kyverno: bool = False,
          k9s: bool = False,
          log_level: str = "",
          log_file: str = "",
          password_manager: bool = False,
+         minio: bool = False,
          version: bool = False):
     """
     Quickly install a k8s distro for a homelab setup. Installs k3s
@@ -162,6 +166,16 @@ def main(k8s: str = "",
     log = setup_logger(log_level, log_file)
     log.debug("Logging configured.")
 
+    # make sure this OS is supported
+    check_os_support()
+
+    if extras:
+        # installs extra tooling such as helm, k9s, and krew
+        from .extras import install_extras
+        install_extras()
+        if not k8s:
+            exit()
+
     # make sure we got a valid k8s distro
     if k8s not in SUPPORTED_DISTROS:
         CONSOLE.print(f'\n☹ Sorry, "[b]{k8s}[/]" is not a currently supported '
@@ -169,9 +183,6 @@ def main(k8s: str = "",
                       f'{SUPPORTED_DISTROS}.\n')
         exit()
 
-    # make sure this OS is supported
-    check_os_support()
-
     if delete:
         # exits the script after deleting the cluster
         delete_cluster(k8s)
@@ -179,14 +190,14 @@ def main(k8s: str = "",
     # make sure the cache directory exists (typically ~/.cache/smol-k8s-lab)
     Path(XDG_CACHE_DIR).mkdir(exist_ok=True)
 
-    # install the actual KIND or k3s cluster
+    # install the actual KIND, k0s, or k3s cluster
     header(f'Installing [green]{k8s}[/] cluster.')
     sub_header('This could take a min ʕ•́  ̫•̀ʔっ♡ ', False)
     install_k8s_distro(k8s)
 
     # make sure helm is installed and the repos are up to date
     from .k8s_tools.homelabHelm import prepare_helm
-    prepare_helm(k8s, argo, external_secret_operator, kyverno)
+    prepare_helm(k8s, argo, external_secret_operator, kyverno, minio)
 
     # needed for metal (non-cloud provider) installs
     header("Installing [b]metallb[/b] so we have an ip address pool")
@@ -214,17 +225,34 @@ def main(k8s: str = "",
         from .k8s_apps.kyverno import install_kyverno
         install_kyverno()
 
+    # minio: local object storage that is s3 compatible
+    if minio:
+        # user can configure a special domain for argocd
+        minio_fqdn = USR_CONFIG_FILE['domain']['minio']
+        minio_console_fqdn = USR_CONFIG_FILE['domain']['minio_console']
+        if USR_CONFIG_FILE['domain'].get('base', False):
+            minio_fqdn = ".".join([minio_fqdn,
+                                   USR_CONFIG_FILE['domain']['base']])
+            minio_console_fqdn = ".".join([minio_console_fqdn,
+                                           USR_CONFIG_FILE['domain']['base']])
+
+        from .k8s_apps.minio import install_minio
+        install_minio(minio_fqdn, minio_console_fqdn, password_manager)
+
     # 🦑 Install Argo CD: continuous deployment app for k8s
     if argo:
-        argocd_fqdn = ".".join([USR_CONFIG_FILE['domain']['argo_cd'],
-                                USR_CONFIG_FILE['domain']['base']])
+        # user can configure a special domain for argocd
+        argocd_fqdn = USR_CONFIG_FILE['domain']['argo_cd']
+        if USR_CONFIG_FILE['domain'].get('base', False):
+            argocd_fqdn = ".".join([argocd_fqdn,
+                                    USR_CONFIG_FILE['domain']['base']])
         from .k8s_apps.argocd import configure_argocd
         configure_argocd(argocd_fqdn, password_manager)
 
     # we're done :D
     print("")
     CONSOLE.print(Panel("\nSmol K8s Lab completed!\n\nMake sure you run:\n"
-                        f"[b]export KUBECONFIG={HOME_DIR}/.kube/kubeconfig\n",
+                        f"[b]export KUBECONFIG={KUBECONFIG}\n",
                         title='[green]◝(ᵔᵕᵔ)◜ Success!',
                         subtitle='♥ [cyan]Have a nice day[/] ♥',
                         border_style="cornflower_blue"))
